# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_railway_global_optspecs
	string join \n json h/help V/version
end

function __fish_railway_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_railway_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_railway_using_subcommand
	set -l cmd (__fish_railway_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c railway -n "__fish_railway_needs_command" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_needs_command" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_needs_command" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_needs_command" -f -a "add" -d 'Add a service to your project'
complete -c railway -n "__fish_railway_needs_command" -f -a "completion" -d 'Generate completion script'
complete -c railway -n "__fish_railway_needs_command" -f -a "connect" -d 'Connect to a database\'s shell (psql for Postgres, mongosh for MongoDB, etc.)'
complete -c railway -n "__fish_railway_needs_command" -f -a "deploy" -d 'Provisions a template into your project'
complete -c railway -n "__fish_railway_needs_command" -f -a "domain" -d 'Generates a domain for a service if there is not a railway provided domain'
complete -c railway -n "__fish_railway_needs_command" -f -a "docs" -d 'Open Railway Documentation in default browser'
complete -c railway -n "__fish_railway_needs_command" -f -a "down" -d 'Remove the most recent deployment'
complete -c railway -n "__fish_railway_needs_command" -f -a "environment" -d 'Change the active environment'
complete -c railway -n "__fish_railway_needs_command" -f -a "init" -d 'Create a new project'
complete -c railway -n "__fish_railway_needs_command" -f -a "link" -d 'Associate existing project with current directory, may specify projectId as an argument'
complete -c railway -n "__fish_railway_needs_command" -f -a "list" -d 'List all projects in your Railway account'
complete -c railway -n "__fish_railway_needs_command" -f -a "login" -d 'Login to your Railway account'
complete -c railway -n "__fish_railway_needs_command" -f -a "logout" -d 'Logout of your Railway account'
complete -c railway -n "__fish_railway_needs_command" -f -a "logs" -d 'View a deploy\'s logs'
complete -c railway -n "__fish_railway_needs_command" -f -a "open" -d 'Open your project dashboard'
complete -c railway -n "__fish_railway_needs_command" -f -a "run" -d 'Run a local command using variables from the active environment'
complete -c railway -n "__fish_railway_needs_command" -f -a "service" -d 'Link a service to the current project'
complete -c railway -n "__fish_railway_needs_command" -f -a "shell" -d 'Open a local subshell with Railway variables available'
complete -c railway -n "__fish_railway_needs_command" -f -a "starship" -d 'Starship Metadata'
complete -c railway -n "__fish_railway_needs_command" -f -a "status" -d 'Show information about the current project'
complete -c railway -n "__fish_railway_needs_command" -f -a "unlink" -d 'Disassociate project from current directory'
complete -c railway -n "__fish_railway_needs_command" -f -a "up" -d 'Upload and deploy project from the current directory'
complete -c railway -n "__fish_railway_needs_command" -f -a "variables" -d 'Show variables for active environment'
complete -c railway -n "__fish_railway_needs_command" -f -a "whoami" -d 'Get the current logged in user'
complete -c railway -n "__fish_railway_needs_command" -f -a "volume" -d 'Manage project volumes'
complete -c railway -n "__fish_railway_needs_command" -f -a "redeploy" -d 'Redeploy the latest deployment of a service'
complete -c railway -n "__fish_railway_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c railway -n "__fish_railway_using_subcommand add" -s d -l database -d 'The name of the database to add' -r -f -a "{postgres\t'',mysql\t'',redis\t'',mongo\t''}"
complete -c railway -n "__fish_railway_using_subcommand add" -s s -l service -d 'The name of the service to create (leave blank for randomly generated)' -r
complete -c railway -n "__fish_railway_using_subcommand add" -s r -l repo -d 'The repo to link to the service' -r
complete -c railway -n "__fish_railway_using_subcommand add" -s i -l image -d 'The docker image to link to the service' -r
complete -c railway -n "__fish_railway_using_subcommand add" -s v -l variables -d 'The "{key}={value}" environment variable pair to set the service variables. Example:' -r
complete -c railway -n "__fish_railway_using_subcommand add" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand add" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c railway -n "__fish_railway_using_subcommand add" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand completion" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand completion" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand completion" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand connect" -s e -l environment -d 'Environment to pull variables from (defaults to linked environment)' -r
complete -c railway -n "__fish_railway_using_subcommand connect" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand connect" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand connect" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand deploy" -s t -l template -d 'The code of the template to deploy' -r
complete -c railway -n "__fish_railway_using_subcommand deploy" -s v -l variable -d 'The "{key}={value}" environment variable pair to set the template variables' -r
complete -c railway -n "__fish_railway_using_subcommand deploy" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand deploy" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c railway -n "__fish_railway_using_subcommand deploy" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand domain" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand domain" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand domain" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand docs" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand docs" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand docs" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand down" -s s -l service -d 'Service to remove the deployment from (defaults to linked service)' -r
complete -c railway -n "__fish_railway_using_subcommand down" -s e -l environment -d 'Environment to remove the deployment from (defaults to linked environment)' -r
complete -c railway -n "__fish_railway_using_subcommand down" -s y -l yes -d 'Skip confirmation dialog'
complete -c railway -n "__fish_railway_using_subcommand down" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand down" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand down" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand environment" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand environment" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand environment" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand init" -s n -l name -d 'Project name' -r
complete -c railway -n "__fish_railway_using_subcommand init" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand init" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand init" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand link" -s e -l environment -d 'Environment to link to' -r
complete -c railway -n "__fish_railway_using_subcommand link" -s p -l project -d 'Project to link to' -r
complete -c railway -n "__fish_railway_using_subcommand link" -s s -l service -d 'The service to link to' -r
complete -c railway -n "__fish_railway_using_subcommand link" -s t -l team -d 'The team to link to. Use "personal" for your personal account' -r
complete -c railway -n "__fish_railway_using_subcommand link" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand link" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand link" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand list" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand list" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand list" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand login" -s b -l browserless -d 'Browserless login'
complete -c railway -n "__fish_railway_using_subcommand login" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand login" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand login" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand logout" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand logout" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand logout" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand logs" -s s -l service -d 'Service to view logs from (defaults to linked service)' -r
complete -c railway -n "__fish_railway_using_subcommand logs" -s e -l environment -d 'Environment to view logs from (defaults to linked environment)' -r
complete -c railway -n "__fish_railway_using_subcommand logs" -s d -l deployment -d 'Show deployment logs'
complete -c railway -n "__fish_railway_using_subcommand logs" -s b -l build -d 'Show build logs'
complete -c railway -n "__fish_railway_using_subcommand logs" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand logs" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand logs" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand open" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand open" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand open" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand run" -s s -l service -d 'Service to pull variables from (defaults to linked service)' -r
complete -c railway -n "__fish_railway_using_subcommand run" -s e -l environment -d 'Environment to pull variables from (defaults to linked environment)' -r
complete -c railway -n "__fish_railway_using_subcommand run" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand run" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand run" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand service" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand service" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand service" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand shell" -s s -l service -d 'Service to pull variables from (defaults to linked service)' -r
complete -c railway -n "__fish_railway_using_subcommand shell" -l silent -d 'Open shell without banner'
complete -c railway -n "__fish_railway_using_subcommand shell" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand shell" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand shell" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand starship" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand starship" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand starship" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand status" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand status" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand status" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand unlink" -s s -l service -d 'Unlink a service'
complete -c railway -n "__fish_railway_using_subcommand unlink" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand unlink" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand unlink" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand up" -s s -l service -d 'Service to deploy to (defaults to linked service)' -r
complete -c railway -n "__fish_railway_using_subcommand up" -s e -l environment -d 'Environment to deploy to (defaults to linked environment)' -r
complete -c railway -n "__fish_railway_using_subcommand up" -s d -l detach -d 'Don\'t attach to the log stream'
complete -c railway -n "__fish_railway_using_subcommand up" -s c -l ci -d 'Stream build logs only, then exit (equivalent to setting $CI=true)'
complete -c railway -n "__fish_railway_using_subcommand up" -l no-gitignore -d 'Don\'t ignore paths from .gitignore'
complete -c railway -n "__fish_railway_using_subcommand up" -l verbose -d 'Verbose output'
complete -c railway -n "__fish_railway_using_subcommand up" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand up" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand up" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand variables" -s s -l service -d 'The service to show/set variables for' -r
complete -c railway -n "__fish_railway_using_subcommand variables" -s e -l environment -d 'The environment to show/set variables for' -r
complete -c railway -n "__fish_railway_using_subcommand variables" -l set -d 'The "{key}={value}" environment variable pair to set the service variables. Example:' -r
complete -c railway -n "__fish_railway_using_subcommand variables" -s k -l kv -d 'Show variables in KV format'
complete -c railway -n "__fish_railway_using_subcommand variables" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand variables" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c railway -n "__fish_railway_using_subcommand variables" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand whoami" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand whoami" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand whoami" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -s s -l service -d 'Service ID' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -s e -l environment -d 'Environment ID' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "list" -d 'List volumes'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "add" -d 'Add a new volume'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "delete" -d 'Delete a volume'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "update" -d 'Update a volume'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "detach" -d 'Detach a volume from a service'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "attach" -d 'Attach a volume to a service'
complete -c railway -n "__fish_railway_using_subcommand volume; and not __fish_seen_subcommand_from list add delete update detach attach help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from list" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from list" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from add" -s m -l mount-path -d 'The mount path of the volume' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from add" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from add" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from delete" -s v -l volume -d 'The ID/name of the volume you wish to delete' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from delete" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from delete" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from update" -s v -l volume -d 'The ID/name of the volume you wish to update' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from update" -s m -l mount-path -d 'The new mount path of the volume (optional)' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from update" -s n -l name -d 'The new name of the volume (optional)' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from update" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from update" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from detach" -s v -l volume -d 'The ID/name of the volume you wish to detach' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from detach" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from detach" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from detach" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from attach" -s v -l volume -d 'The ID/name of the volume you wish to attach' -r
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from attach" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from attach" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from attach" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "list" -d 'List volumes'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "add" -d 'Add a new volume'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a volume'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "update" -d 'Update a volume'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "detach" -d 'Detach a volume from a service'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "attach" -d 'Attach a volume to a service'
complete -c railway -n "__fish_railway_using_subcommand volume; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c railway -n "__fish_railway_using_subcommand redeploy" -s s -l service -d 'The service ID/name to redeploy from' -r
complete -c railway -n "__fish_railway_using_subcommand redeploy" -s y -l yes -d 'Skip confirmation dialog'
complete -c railway -n "__fish_railway_using_subcommand redeploy" -l json -d 'Output in JSON format'
complete -c railway -n "__fish_railway_using_subcommand redeploy" -s h -l help -d 'Print help'
complete -c railway -n "__fish_railway_using_subcommand redeploy" -s V -l version -d 'Print version'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "add" -d 'Add a service to your project'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "completion" -d 'Generate completion script'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "connect" -d 'Connect to a database\'s shell (psql for Postgres, mongosh for MongoDB, etc.)'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "deploy" -d 'Provisions a template into your project'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "domain" -d 'Generates a domain for a service if there is not a railway provided domain'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "docs" -d 'Open Railway Documentation in default browser'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "down" -d 'Remove the most recent deployment'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "environment" -d 'Change the active environment'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "init" -d 'Create a new project'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "link" -d 'Associate existing project with current directory, may specify projectId as an argument'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "list" -d 'List all projects in your Railway account'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "login" -d 'Login to your Railway account'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "logout" -d 'Logout of your Railway account'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "logs" -d 'View a deploy\'s logs'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "open" -d 'Open your project dashboard'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "run" -d 'Run a local command using variables from the active environment'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "service" -d 'Link a service to the current project'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "shell" -d 'Open a local subshell with Railway variables available'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "starship" -d 'Starship Metadata'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "status" -d 'Show information about the current project'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "unlink" -d 'Disassociate project from current directory'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "up" -d 'Upload and deploy project from the current directory'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "variables" -d 'Show variables for active environment'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "whoami" -d 'Get the current logged in user'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "volume" -d 'Manage project volumes'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "redeploy" -d 'Redeploy the latest deployment of a service'
complete -c railway -n "__fish_railway_using_subcommand help; and not __fish_seen_subcommand_from add completion connect deploy domain docs down environment init link list login logout logs open run service shell starship status unlink up variables whoami volume redeploy help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c railway -n "__fish_railway_using_subcommand help; and __fish_seen_subcommand_from volume" -f -a "list" -d 'List volumes'
complete -c railway -n "__fish_railway_using_subcommand help; and __fish_seen_subcommand_from volume" -f -a "add" -d 'Add a new volume'
complete -c railway -n "__fish_railway_using_subcommand help; and __fish_seen_subcommand_from volume" -f -a "delete" -d 'Delete a volume'
complete -c railway -n "__fish_railway_using_subcommand help; and __fish_seen_subcommand_from volume" -f -a "update" -d 'Update a volume'
complete -c railway -n "__fish_railway_using_subcommand help; and __fish_seen_subcommand_from volume" -f -a "detach" -d 'Detach a volume from a service'
complete -c railway -n "__fish_railway_using_subcommand help; and __fish_seen_subcommand_from volume" -f -a "attach" -d 'Attach a volume to a service'
